Nickw-Flask-Utils
+++++++++++++++++

.. image:: https://travis-ci.org/nickw444/nickw-flask-utils.svg
    :target: https://travis-ci.org/nickw444/nickw-flask-utils

.. image:: https://img.shields.io/github/issues/nickw444/nickw-flask-utils.svg
    :target: https://github.com/nickw444/nickw-flask-utils

.. image:: https://img.shields.io/pypi/v/nickw-flask-utils.svg
    :target: https://pypi.python.org/pypi/nickw-flask-utils/

A set of utilities to make working with flask web applications easier.

This repository contains a collection of web utilities that are common across many of our projects.

It makes the most sense to keep these in a common repository to promote code re-use and modularity.

`View the Full Documentation at ReadTheDocs <http://nickw-flask-utils.readthedocs.org/en/latest/>`_

